@@ -1,6 +1,5 @@
 #' Get job from registry by id.
-#' @param reg [\code{\link{Registry}}]\cr
-#'   Registry.
+#' @template arg_reg
 #' @param id [\code{integer(1)}]\cr
 #'   Id of job.
 #' @param check.id [\code{logical(1)}]\cr
@@ -10,13 +9,12 @@
 #' @export
 getJob = function(reg, id, check.id = TRUE) {
   if (check.id)
-    id = checkId(reg, id)
+    id = checkIds(reg, id, len = 1L)
   getJobs(reg, id, check.ids = FALSE)[[1L]]
 }
 
 #' Get jobs from registry by id.
-#' @param reg [\code{\link{Registry}}]\cr
-#'   Registry.
+#' @template arg_reg
 #' @param ids [\code{integer}]\cr
 #'   Ids of jobs.
 #'   Default is all jobs.
@@ -26,7 +24,7 @@ getJob = function(reg, id, check.id = TRUE) {
 #' @return [list of \code{\link{Job}}].
 #' @export
 getJobs = function(reg, ids, check.ids = TRUE) {
-  checkRegistry(reg)
+  checkRegistry(reg, writeable = FALSE)
   # syncRegistry(reg) NOT!
   assertFlag(check.ids)
   UseMethod("getJobs")
@@ -35,9 +33,7 @@ getJobs = function(reg, ids, check.ids = TRUE) {
 #' @method getJobs Registry
 #' @export
 getJobs.Registry = function(reg, ids, check.ids = TRUE) {
-  if (! missing(ids) && check.ids) {
+  if (!missing(ids) && check.ids)
     ids = checkIds(reg, ids)
-  }
-
   dbGetJobs(reg, ids)
 }
